fn crate_path(root_file_path: &VfsPath) -> Option<VfsPath>Expand description
Searches for the directory of a Rust crate given this crate’s root file path.
Arguments
root_file_path: The path to the root file of the crate.
Returns
An Option value representing the path to the directory of the crate with the given
name, if such a crate is found. If no crate with the given name is found, this function
returns None.